Utilizado para gerar o relatorio ensalamento e inserir sugestoes de salas caso necessario

Funcoes 

- gerarExcel - Recebe o caminho de 4 arquivos,o arquivo da carga horaria, arquivo de capacidade, arquivo XML e o nome do arquivo de saida
